@@ -59,7 +59,7 @@ use base qw( Exporter DynaLoader );
 sub dl_load_flags { 0x01 } # global option
 
 BEGIN {
-  $VERSION = '0.01';
+  $VERSION = '1.01';
   bootstrap Net::Silk $VERSION;
 }
 
@@ -197,6 +197,18 @@ END { module_destroy() }
 
 ###
 
+use Net::Silk::IPWildcard;
+use Net::Silk::Site;
+use Net::Silk::IPAddr;
+use Net::Silk::IPSet;
+use Net::Silk::ProtoPort;
+use Net::Silk::Pmap;
+use Net::Silk::File;
+use Net::Silk::Bag;
+use Net::Silk::TCPFlags;
+
+###
+
 1;
 
 __END__
@@ -258,7 +270,7 @@ L<Net::Silk::RWRec>, L<Net::Silk::IPSet>, L<Net::Silk::IPWildcard>, L<Net::Silk:
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2011-2014 by Carnegie Mellon University
+Copyright (C) 2011-2015 by Carnegie Mellon University
 
 Use of the Net-Silk library and related source code is subject to the
 terms of the following licenses:
