@@ -737,7 +737,7 @@ Remove all IP addresses from this set.
 =head1 OPERATORS
 
 The following operators are overloaded and work with
-C<Net::Silk::TCPFlags> objects:
+C<Net::Silk::IPSet> objects:
 
   &             ==
   |             !=
@@ -765,7 +765,7 @@ L<Net::Silk>, L<Net::Silk::RWRec>, L<Net::Silk::IPWildcard>, L<Net::Silk::Bag>,
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2011-2014 by Carnegie Mellon University
+Copyright (C) 2011-2015 by Carnegie Mellon University
 
 Use of the Net-Silk library and related source code is subject to the
 terms of the following licenses:
